@@ -121,6 +121,7 @@ get_elev_raster <- function(locations, z, prj = NULL,
                    that the OpenTopography API Limit will likely be exceeded."))
   }
   
+  
   # Pass of locations to APIs to get data as raster
   if(src == "aws") {
     raster_elev <- get_aws_terrain(locations, z, prj = prj, expand = expand, ...)
@@ -129,7 +130,7 @@ get_elev_raster <- function(locations, z, prj = NULL,
   }
   if(clip != "tile"){
     message(paste("Clipping DEM to", clip))
-    #raster_elev not web merc from Open Topo - need to deal with that.
+    
     raster_elev <- clip_it(raster_elev, locations, expand, clip)
   }
  
@@ -193,6 +194,7 @@ get_aws_terrain <- function(locations, z, prj, expand=NULL,
   
   base_url <- "https://s3.amazonaws.com/elevation-tiles-prod/geotiff"
   
+  #tiles <- get_tilexy_coords(locations, z)
   tiles <- get_tilexy(bbx,z)
   
   urls  <-  sprintf("%s/%s/%s/%s.tif", base_url, z, tiles[,1], tiles[,2])
@@ -247,13 +249,13 @@ get_aws_terrain <- function(locations, z, prj, expand=NULL,
                                     } 
                                     tmpfile
                                   })
-    future::plan(future::sequential)
-    #future:::ClusterRegistry("stop")
   }
   })
-  
+
   merged_elevation_grid <- merge_rasters(dem_list, target_prj = prj)
   
+  if(serial==FALSE){future::plan(future::sequential)}
+  
   merged_elevation_grid
 }
 
@@ -285,14 +287,22 @@ merge_rasters <- function(raster_list,  target_prj, method = "bilinear", returnR
   sf::gdal_utils(util = "warp", 
                  source = files, 
                  destination = destfile,
-                 options = c("-t_srs", as.character(target_prj),
-                             "-r", method)
+                 options = c("-r", method)
              )
+  # Using two steps now as gdal with one step introduced NA's along seams
+  # Slower but more accurate!
+  destfile2 <- tempfile(fileext = ".tif")
+  sf::gdal_utils(util = "warp", 
+                 source = destfile, 
+                 destination = destfile2,
+                 options = c("-r", method,
+                   "-t_srs", as.character(target_prj))
+  )
   
   if(returnRaster){
-    raster::raster(destfile)
+    raster::raster(destfile2)
   } else {
-    destfile
+    destfile2
   }
 }
 
@@ -320,6 +330,9 @@ merge_rasters <- function(raster_list,  target_prj, method = "bilinear", returnR
 #' @export
 #' @keywords internal
 get_opentopo <- function(locations, src, prj, expand=NULL, ...){
+  
+  api_key <- get_opentopo_key()
+  
   # Expand (if needed) and re-project bbx to ll_geo
   bbx <- proj_expand(locations,prj,expand)
   
@@ -335,7 +348,8 @@ get_opentopo <- function(locations, src, prj, expand=NULL, ...){
                 "&south=",min(bbx[2,]),
                 "&east=",max(bbx[1,]),
                 "&north=",max(bbx[2,]),
-                "&outputFormat=GTiff")
+                "&outputFormat=GTiff",
+                "&API_Key=", api_key)
   
   message("Downloading OpenTopography DEMs")
   resp <- httr::GET(url,httr::write_disk(tmpfile,overwrite=TRUE), 
@@ -348,3 +362,26 @@ get_opentopo <- function(locations, src, prj, expand=NULL, ...){
   dem <- merge_rasters(tmpfile, target_prj = prj)
   dem
 }
+
+#' Store OpenTopography Key
+#' 
+#' This function stores an OpenTopgrapy key in a local .Renviron file. If the
+#' .Renviron file exists, the key will be appended. This will typically only 
+#' need to be done once per machine.   
+#' 
+#' 
+#' @param key An OpenTopography API Key as a character.  For details on obtaining an 
+#'            OpenTopgraphy key see \url{https://opentopography.org/blog/introducing-api-keys-access-opentopography-global-datasets}. 
+#' @export
+set_opentopo_key <- function(key){
+  home <- normalizePath("~/")
+  if(Sys.getenv("OPENTOPO_KEY")==""){ 
+    cat(paste0("OPENTOPO_KEY=", key, "\n"), file = paste0(home, "/.Renviron"), 
+        append = TRUE)
+    message("Your OpenTopography Key has been added to .Renviron.
+            You will need to restart R for the changes to take effect.")
+  } else {
+    message("An existing OpenTopography Key already exists.
+            To edit try usethis::edit_r_environ().")
+  } 
+}
\ No newline at end of file
